@@ -17,8 +17,6 @@ from datetime import datetime
 from pathlib import Path
 from quid.passager.CitationSource import CitationSource
 from quid.passager.CitationSourceLink import CitationSourceLink
-from quid.passager.ImportantSegment import ImportantSegment
-from quid.passager.ImportantSegmentLink import ImportantSegmentLink
 from quid.passager.SourceSegment import SourceSegment
 from quid.passager.TargetLocation import TargetLocation
 from quid.passager.TargetLocationSelection import TargetLocationSelection
@@ -91,8 +89,7 @@ def __json_encoder(obj, strip):
     if isinstance(obj, set):
         return list(obj)
 
-    if isinstance(obj, (TargetText, CitationSourceLink, TargetLocationSelection, TargetTextLocationLink,
-                        ImportantSegmentLink, Info)):
+    if isinstance(obj, (TargetText, CitationSourceLink, TargetLocationSelection, TargetTextLocationLink, Info)):
         return obj.__dict__
 
     if isinstance(obj, CitationSource):
@@ -125,17 +122,6 @@ def __json_encoder(obj, strip):
 
         return result_dict
 
-    if isinstance(obj, ImportantSegment):
-        if not strip:
-            return obj.__dict__
-
-        result_dict = obj.__dict__
-
-        if len(result_dict['text']) > 40:
-            text = result_dict['text']
-            result_dict['text'] = text[0:20] + ' [\u2026] ' + text[-20:]
-
-        return result_dict
     elif isinstance(obj, SourceSegment):
         if not strip:
             return obj.__dict__
